.. _astro-source:

***************************
Astrophysical source models
***************************

Introduction
============

The `gammapy.astro.source` module contains classes of source models, which can
be used for population synthesis of galactic gamma-ray sources.

.. TODO: add basic example.

Using gammapy.astro.source
==========================

The following source models are available:

.. toctree::
    :maxdepth: 1

    snr
    pwn
    pulsar

